You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@openoffice.apache.org by ma...@apache.org on 2014/05/28 23:17:38 UTC

svn commit: r1598142 - /openoffice/ooo-site/trunk/content/download/test/download_droplist.js

Author: marcus
Date: Wed May 28 21:17:38 2014
New Revision: 1598142

URL: http://svn.apache.org/r1598142
Log:
Updated code for showing not supported platforms as error message

Modified:
    openoffice/ooo-site/trunk/content/download/test/download_droplist.js

Modified: openoffice/ooo-site/trunk/content/download/test/download_droplist.js
URL: http://svn.apache.org/viewvc/openoffice/ooo-site/trunk/content/download/test/download_droplist.js?rev=1598142&r1=1598141&r2=1598142&view=diff
==============================================================================
--- openoffice/ooo-site/trunk/content/download/test/download_droplist.js (original)
+++ openoffice/ooo-site/trunk/content/download/test/download_droplist.js Wed May 28 21:17:38 2014
@@ -73,6 +73,7 @@ function initVars() {
 	LANG_ISO				= "";	 // The language as ISO code
 	LANG_ARRAY				= "";	 // This array contains all language specific data
 	UI_PLATFORM				= "";	 // The platform as readable string
+	UI_PLATFORM_NO_SUP			= "";	 // The platform as readable string, if not supported
 	URL_PLATFORM				= "";	 // The platform as part of the download URL
 	OLD_PLATFORM				= false; // Is the browser platform old (true) or not (false)?
 	RELEASE_MATRIX_PLATFORM_POS_FULL	= 0;	 // The position of the platform in the release matrix array
@@ -128,6 +129,7 @@ function alertDbg( location ) {
 	+ "RELEASE_MATRIX_PLATFORM: "		+ "\t\t\t"		+ RELEASE_MATRIX_PLATFORM		+ "\n"
 	+ "RELEASE_MATRIX_LANG: "		+ "\t\t\t\t"		+ RELEASE_MATRIX_LANG			+ "\n"
 	+ "UI_PLATFORM: "			+ "\t\t\t\t\t\t"	+ UI_PLATFORM				+ "\n"
+	+ "UI_PLATFORM_NO_SUP: "		+ "\t\t\t\t"		+ UI_PLATFORM_NO_SUP			+ "\n"
 	+ "URL_PLATFORM: "			+ "\t\t\t\t\t\t"	+ URL_PLATFORM				+ "\n"
 	+ "OLD_PLATFORM: "			+ "\t\t\t\t\t"		+ OLD_PLATFORM				+ "\n"
 	+ "LANG_SEL: "				+ "\t\t\t\t\t\t"	+ LANG_SEL				+ "\n"
@@ -731,7 +733,7 @@ function getLangSel() {
 	}
 
 	LANG_ISO = LANG_SEL;
-	getLanguage();
+//	getLanguage();
 
 //	alert( "getLangSel() : End" + "\n\n" + "LANG_ISO: " + LANG_ISO + "\n" + "LANG_SEL: " + LANG_SEL );
 
@@ -1219,12 +1221,12 @@ function getLinkSel( rel_mode ) {
 	}
 
 	// If recognized platform is not 'Windows', 'Linux' or 'Mac', show the none-availability to the user.
-	if( URL_PLATFORM == "" ) {
+	if( UI_PLATFORM_NO_SUP != "" ) {
 		// Show an error message that the chosen items do not lead to a download.
 		error_text =  [ "No full installation available", "Please select another language, platform or version.",
 				"No language pack available", "Please select another language, platform or version.",
-				"Apache OpenOffice " + VERSION_SEL + " for <b>" + UI_PLATFORM + "</b> is not available. "
-			      + "<br />Please select a platform for Windows, Linux or OS X." ];
+				"Apache OpenOffice " + VERSION_SEL + " for <b>" + UI_PLATFORM_NO_SUP + "</b> is not "
+			      + "available. <br />Please select a platform for Windows, Linux or OS X." ];
 
 		showErrorMessage( error_text );
 
@@ -1390,12 +1392,13 @@ function getLinkSel( rel_mode ) {
 function getPlatform() {
 	// For more help or data see: "http://www.useragentstring.com".
 
-	var os		= navigator.platform.toLowerCase();	// Get the platform string in lower cases.
-	var ua		= navigator.userAgent.toLowerCase();	// Get the User Agent string in lower cases.
-	var av		= navigator.appVersion.toLowerCase();	// Get the application version in lower cases.
-	UI_PLATFORM	= "";					// Delete any previously set string.
-	URL_PLATFORM	= "";					// Delete any previously set string.
-	EXTENSION	= "";					// Delete any previously set string.
+	var os		   = navigator.platform.toLowerCase();	 // Get the platform string in lower cases.
+	var ua		   = navigator.userAgent.toLowerCase();	 // Get the User Agent string in lower cases.
+	var av		   = navigator.appVersion.toLowerCase(); // Get the application version in lower cases.
+	UI_PLATFORM	   = "";				 // Delete any previously set string.
+	UI_PLATFORM_NO_SUP = "";				 // Delete any previously set string.
+	URL_PLATFORM	   = "";				 // Delete any previously set string.
+	EXTENSION	   = "";				 // Delete any previously set string.
 
 	// Add ECMA262-5 Array methods if not supported natively.
 	// To workaround that MSIE 8 and older do not support this function.
@@ -1416,67 +1419,68 @@ function getPlatform() {
 	}
 
 	if( os ) {
-		// Recognized but not supported platforms/OS, set $UI_PLATFORM to show it to the user.
-		if( os.indexOf( "aix"			) != -1 )	UI_PLATFORM	= "IBM AIX";
-		if( os.indexOf( "alphaserver"		) != -1 )	UI_PLATFORM	= "AlphaServer";
-		if( os.indexOf( "amiga"			) != -1 )	UI_PLATFORM	= "AmigaOS";
+		// Recognized but not supported platforms/OS, set $UI_PLATFORM_NO_SUP to show it to the user.
+		if( os.indexOf( "aix"			) != -1 )	UI_PLATFORM_NO_SUP	= "IBM AIX";
+		if( os.indexOf( "alphaserver"		) != -1 )	UI_PLATFORM_NO_SUP	= "AlphaServer";
+		if( os.indexOf( "amiga"			) != -1 )	UI_PLATFORM_NO_SUP	= "AmigaOS";
 		if( ua.indexOf( "android"		) != -1 ||
-		    av.indexOf( "android"		) != -1 )	UI_PLATFORM	= "Android mobile devices";
-		if( os.indexOf( "arm"			) != -1 )	UI_PLATFORM	= "ARM mobile devices";
-		if( ua.indexOf( "blackberry"		) != -1 )	UI_PLATFORM	= "Blackberry smartphones";
-		if( ua.indexOf( "brew"			) != -1 )	UI_PLATFORM	= "smartphones (BREW)";
-		if( ua.indexOf( "ce.net"		) != -1 )	UI_PLATFORM	= "mobile phones (Windows CE)";
-		if( os.indexOf( "darwin"		) != -1 )	UI_PLATFORM	= "Darwin";
-		if( os.indexOf( "dragonfly"		) != -1 )	UI_PLATFORM	= "DragonFly BSD";
-		if( os.indexOf( "freebsd"		) != -1 )	UI_PLATFORM	= "FreeBSD (PKG)";
-		if( ua.indexOf( "hiptop"		) != -1 )	UI_PLATFORM	= "smartphones (Hiptop)";
+		    av.indexOf( "android"		) != -1 )	UI_PLATFORM_NO_SUP	= "Android mobile devices";
+		if( os.indexOf( "arm"			) != -1 )	UI_PLATFORM_NO_SUP	= "ARM mobile devices";
+		if( ua.indexOf( "blackberry"		) != -1 )	UI_PLATFORM_NO_SUP	= "Blackberry smartphones";
+		if( ua.indexOf( "brew"			) != -1 )	UI_PLATFORM_NO_SUP	= "smartphones (BREW)";
+		if( os.indexOf( "win"			) != -1 ||
+		    os.indexOf( "windows"		) != -1 )
+			if( ua.indexOf( "mobile"	) != -1 ||
+			    ua.indexOf( "phone"		) != -1 )	UI_PLATFORM_NO_SUP	= "smartphones (Windows Phone)";
+		if( ua.indexOf( "ce.net"		) != -1 )	UI_PLATFORM_NO_SUP	= "mobile phones (Windows CE)";
+		if( os.indexOf( "darwin"		) != -1 )	UI_PLATFORM_NO_SUP	= "Darwin";
+		if( os.indexOf( "dragonfly"		) != -1 )	UI_PLATFORM_NO_SUP	= "DragonFly BSD";
+		if( os.indexOf( "freebsd"		) != -1 )	UI_PLATFORM_NO_SUP	= "FreeBSD (PKG)";
+		if( ua.indexOf( "hiptop"		) != -1 )	UI_PLATFORM_NO_SUP	= "smartphones (Hiptop)";
 		if( ua.indexOf( "ipad"			) != -1 ||
 		    ua.indexOf( "iphone"		) != -1 ||
-		    ua.indexOf( "ipod"			) != -1	)	UI_PLATFORM	= "Apple iPhone/iPad/iPod";
-		if( os.indexOf( "irix"			) != -1 )	UI_PLATFORM	= "IRIX";
-		if( ua.indexOf( "kindle"		) != -1 )	UI_PLATFORM	= "Kindle mobile devices";
-		if( os.indexOf( "netbsd"		) != -1 )	UI_PLATFORM	= "NetBSD";
-		if( ua.indexOf( "nintendo"		) != -1 )	UI_PLATFORM	= "Nintendo game console";
-		if( ua.indexOf( "nokia"			) != -1 )	UI_PLATFORM	= "Nokia mobile devices";
-		if( os.indexOf( "openbsd"		) != -1 )	UI_PLATFORM	= "OpenBSD";
-		if( os.indexOf( "os/2"			) != -1 )	UI_PLATFORM	= "OS/2";
-		if( ua.indexOf( "palm"			) != -1 )	UI_PLATFORM	= "mobile phones (Palm OS)";
-		if( os.indexOf( "pcbsd"			) != -1 )	UI_PLATFORM	= "PC-BSD";
-		if( ua.indexOf( "pike"			) != -1 )	UI_PLATFORM	= "mobile phones (Pike)";
-		if( ua.indexOf( "playstation"		) != -1 )	UI_PLATFORM	= "Sony Playstation";
+		    ua.indexOf( "ipod"			) != -1	)	UI_PLATFORM_NO_SUP	= "Apple iPhone/iPad/iPod";
+		if( os.indexOf( "irix"			) != -1 )	UI_PLATFORM_NO_SUP	= "IRIX";
+		if( ua.indexOf( "kindle"		) != -1 )	UI_PLATFORM_NO_SUP	= "Amazon Kindle";
+		if( os.indexOf( "netbsd"		) != -1 )	UI_PLATFORM_NO_SUP	= "NetBSD";
+		if( ua.indexOf( "nintendo"		) != -1 )	UI_PLATFORM_NO_SUP	= "Nintendo game console";
+		if( ua.indexOf( "nokia"			) != -1 )	UI_PLATFORM_NO_SUP	= "Nokia mobile devices";
+		if( os.indexOf( "openbsd"		) != -1 )	UI_PLATFORM_NO_SUP	= "OpenBSD";
+		if( os.indexOf( "os/2"			) != -1 )	UI_PLATFORM_NO_SUP	= "OS/2";
+		if( ua.indexOf( "palm"			) != -1 )	UI_PLATFORM_NO_SUP	= "mobile phones (Palm OS)";
+		if( os.indexOf( "pcbsd"			) != -1 )	UI_PLATFORM_NO_SUP	= "PC-BSD";
+		if( ua.indexOf( "pike"			) != -1 )	UI_PLATFORM_NO_SUP	= "mobile phones (Pike)";
+		if( ua.indexOf( "playstation"		) != -1 )	UI_PLATFORM_NO_SUP	= "Sony Playstation";
 		if( ua.indexOf( "power_pc"		) != -1 ||
-		    ua.indexOf( "ppc"			) != -1 ) {	UI_PLATFORM	= "Mac OS PPC (DMG)";
-									OLD_PLATFORM	= true;
-		}
-		if( ua.indexOf( "psp"			) != -1 )	UI_PLATFORM	= "Sony Playstation Portable";
-		if( os.indexOf( "qnx"			) != -1 )	UI_PLATFORM	= "QNX";
-		if( ua.indexOf( "s60"	        	) != -1 )	UI_PLATFORM	= "mobile phones (Series60/S60)";
-		if( ua.indexOf( "series60"		) != -1 )	UI_PLATFORM	= "mobile phones (Series60/S60)";
-		if( ua.indexOf( "sun4u"			) != -1 ) {	UI_PLATFORM	= "Solaris SPARC (PKG)";
-									OLD_PLATFORM	= true;
-		}
-		if( os.indexOf( "sunos"			) != -1 ) {	UI_PLATFORM	= "Solaris x86 (PKG)";
-									OLD_PLATFORM	= true;
+		    ua.indexOf( "ppc"			) != -1 ) {	UI_PLATFORM_NO_SUP	= "Mac OS PPC (DMG)";
+									OLD_PLATFORM		= true;
 		}
-		if( ua.indexOf( "symbian"		) != -1 )	UI_PLATFORM	= "mobile phones (Symbian OS)";
-		if( ua.indexOf( "symbos"		) != -1 )	UI_PLATFORM	= "mobile phones (Symbian OS)";
-		if( os.indexOf( "vms"			) != -1 )	UI_PLATFORM	= "OpenVMS";
-		if( ua.indexOf( "webos"			) != -1 )	UI_PLATFORM	= "mobile phones (Palm webOS)";
-		if( ua.indexOf( "widerweb"		) != -1 )	UI_PLATFORM	= "mobile phones (WiderWeb)";
-		if( ua.indexOf( "wii"			) != -1 )	UI_PLATFORM	= "Nintendo Wii game console";
-		if( os.indexOf( "x11"			) != -1 )	UI_PLATFORM	= "unknown OS (X11 support)";
+		if( ua.indexOf( "psp"			) != -1 )	UI_PLATFORM_NO_SUP	= "Sony Playstation Portable";
+		if( os.indexOf( "qnx"			) != -1 )	UI_PLATFORM_NO_SUP	= "QNX";
+		if( ua.indexOf( "s60"	        	) != -1 )	UI_PLATFORM_NO_SUP	= "mobile phones (S60)";
+		if( ua.indexOf( "sun4u"			) != -1 ) {	UI_PLATFORM_NO_SUP	= "Solaris SPARC (PKG)";
+									OLD_PLATFORM		= true;
+		}
+		if( os.indexOf( "sunos"			) != -1 ) {	UI_PLATFORM_NO_SUP	= "Solaris x86 (PKG)";
+									OLD_PLATFORM		= true;
+		}
+		if( ua.indexOf( "symbian"		) != -1 )	UI_PLATFORM_NO_SUP	= "mobile phones (Symbian OS)";
+		if( ua.indexOf( "symbos"		) != -1 )	UI_PLATFORM_NO_SUP	= "mobile phones (Symbian OS)";
+		if( os.indexOf( "vms"			) != -1 )	UI_PLATFORM_NO_SUP	= "OpenVMS";
+		if( ua.indexOf( "webos"			) != -1 )	UI_PLATFORM_NO_SUP	= "mobile phones (Palm webOS)";
+		if( ua.indexOf( "widerweb"		) != -1 )	UI_PLATFORM_NO_SUP	= "mobile phones (WiderWeb)";
+		if( ua.indexOf( "wii"			) != -1 )	UI_PLATFORM_NO_SUP	= "Nintendo Wii game console";
+		if( os.indexOf( "x11"			) != -1 )	UI_PLATFORM_NO_SUP	= "unknown OS (X11 support)";
 
-		// If the $UI_PLATFORM variable is already filled, something was recognized and no more work is need.
-		if( UI_PLATFORM != "" )
+		// If $UI_PLATFORM_NO_SUP is already filled, something was recognized and no more work is needed.
+		if( UI_PLATFORM_NO_SUP != "" )
 			return;
 
-		// Windows, x86 or mobile?
+		// Windows?
 		if( os.indexOf( "win"			) != -1 ||
 		    os.indexOf( "windows"		) != -1 ) {	UI_PLATFORM	= "Windows (EXE)";
 									URL_PLATFORM	= "Win_x86_install";
 									EXTENSION	= ".exe";
-		     if( ua.indexOf( "mobile"		) != -1 ||
-			 ua.indexOf( "phone"		) != -1 )	UI_PLATFORM	= "Windows Mobile device";
 		}
 
 		// Linux, x86 or x86-64, DEB or RPM?